Discover Packages
github.com/carneades/carneades-4
src
engine
caes
encoding
aif
package
Version:
v0.0.0-...-d19d543
Opens a new window with list of versions in this module.
Published: Oct 15, 2024
License: MPL-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type AIF struct {
Edges []Edge `json:"edges"`
Nodes []Node `json:"nodes"`
}
type Edge struct {
Id string `json:"edgeID"`
From string `json:"fromID"`
FormEdge string `json:"formEdgeID"`
To string `json:"toID"`
}
type Node struct {
Id string `json:"nodeID"`
Text string `json:"text"`
Scheme string `json:"scheme"`
Timestamp string `json:"timestamp"`
Type string `json:"type"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.