validation

package
v0.0.0-...-d19d543 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2024 License: MPL-2.0 Imports: 5 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Category

type Category int

The category of the problem

const (
	IMPORT Category = iota
	STATEMENT
	ISSUE
	ARGUMENT
	ASSUMPTION
	EXPECTEDLABELING
	LANGUAGE
	SCHEME  // Argument Scheme
	ISCHEME // Issue Scheme
)

func (Category) String

func (c Category) String() string

type Problem

type Problem struct {
	Category    Category
	Id          string // id of the affected object, if available
	Description string // brief description of the problem, without referencing the category or object id
	Expression  string // the affected part of the object with the problem.
}

Problem represents an error in some Carneades source file

func Validate

func Validate(ag *caes.ArgGraph) []Problem

Validate an argument graph

Jump to