Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Problem ¶
type Problem struct {
Category Category
Id string // id of the affected object, if available
Description string // brief description of the problem, without referencing the category or object id
Expression string // the affected part of the object with the problem.
}
Problem represents an error in some Carneades source file
Click to show internal directories.
Click to hide internal directories.